@@ -28,8 +28,8 @@ impl<T: JamsocketContext> JamsocketServiceFactory<T> for WasmHostFactory {
 
         match result {
             Ok(r) => Some(r),
-            Err(e) => {
-                log::error!("Could not build a WasmHost, got: {:?}", &e);
+            Err(error) => {
+                tracing::error!(?error, "Could not build a WasmHost");
                 None
             }
         }
@@ -42,7 +42,7 @@ impl WasmHostFactory {
         P: AsRef<Path>,
     {
         let engine = Engine::default();
-        log::info!("Loading WebAssembly module {:?}", wasm_file.as_ref());
+        tracing::info!(wasm_file=?wasm_file.as_ref(), "Loading WebAssembly module");
         let module = Module::from_file(&engine, wasm_file)?;
 
         Ok(WasmHostFactory {
@@ -50,4 +50,8 @@ impl WasmHostFactory {
             module: Arc::new(module),
         })
     }
+
+    pub fn new_with_shared_module(engine: Arc<Engine>, module: Arc<Module>) -> Self {
+        WasmHostFactory { engine, module }
+    }
 }
